/*------------------------------------------------------------------------
 *    Graphic library
 *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
 *    jpc@cereve.enpc.fr 
 --------------------------------------------------------------------------*/

#ifndef __PERIWIN_H__
#define __PERIWIN_H__


 extern void C2F(drawarc)();
 extern void C2F(fillarcs)();
 extern void C2F(drawarcs)();
 extern void C2F(fillpolyline)();
 extern void C2F(drawaxis)();
 extern void C2F(cleararea)();
 extern void C2F(clearwindow)();
 extern void C2F(xclick)();
 extern void C2F(xclick_any)();
 extern void C2F(xgetmouse)();
 extern void C2F(xend)();
 extern void C2F(fillarc)();
 extern void C2F(viderbuff)();
 extern void C2F(fillrectangle)();
 extern void C2F(MissileGCget)();
 extern void C2F(initgraphic)();
 extern void C2F(drawpolyline)();
 extern void C2F(fillpolylines)();
 extern void C2F(drawpolylines)();
 extern void C2F(drawpolymark)();
 extern void C2F(setpopupname)();
 extern void C2F(displaynumbers)();
 extern void C2F(xpause)();
 extern void C2F(drawrectangle)();
 extern void C2F(drawrectangles)();
 extern void C2F(drawsegments)();
 extern void C2F(xselgraphic)();
 extern void C2F(MissileGCset)();
 extern void C2F(SetDriver)();
 extern void C2F(displaystring)();
 extern void C2F(boundingbox)();
 extern void C2F(drawarrows)();
 extern void C2F(loadfamily)();
 extern void  C2F(queryfamily)();
 extern void C2F(xinfo)();
 
#endif /* __PERIWIN_H__ */


